class OrientDb::Base
  include OrientDb::Methods::GenericMethods

  def initialize(orientdb_connection)
    @connection = orientdb_connection
  end

  def connection
    @connection
  end

  def find(id)
    result = get_by_rid(id)
    build_object result
  end


  def all
    objects_hash = connection.query "SELECT FROM #{odb_class}", :limit => -1
    objects = build_objects(objects_hash) || []
  end

  def all_from_offset_to_limit(offset, limit)
    objects_hash = connection.query "SELECT FROM #{odb_class} LIMIT #{limit} SKIP #{offset}", :limit => limit
    objects = build_objects(objects_hash) || []
  end

  def destroy(object)
    connection.command sprintf("DELETE VERTEX %s", object.id)
  end

  def create(object)
    if object.valid?
      hash = build_hash(object)
      result = connection.create_document(hash)
      object.id = result["@rid"]
    end
    object
  end

  def build_objects(hash=[])
    objects = []
    hash.each do |h|
      objects << build_object(h)
    end
    objects
  end

  def build_hash(object)
    hash = {}
    hash["@class"] = odb_class
    object.instance_variables.each do |var|
      var_name = sanitize_orientdb_vars(var)
      hash[var_name] = object.instance_variable_get(var)
    end
    hash
  end

  def sanitize_orientdb_vars(var)
    var.to_s.gsub(/\A@/, "")
  end

  def build_object(args={})
    raise NoMethodError, "You must implement this method"
  end

  protected

  def odb_class
    raise NoMethodError, "You must implement this method"
  end

end
